@@ -832,14 +832,7 @@ void M_DrawLoad(void)
     for (i = 0;i < load_end; i++)
     {
 	M_DrawSaveLoadBorder(LoadDef.x,LoadDef.y+LINEHEIGHT*i);
-
-	// [crispy] shade empty savegame slots
-	if (!LoadMenu[i].status)
-	    dp_translation = cr[CR_DARK];
-
 	M_WriteText(LoadDef.x,LoadDef.y+LINEHEIGHT*i,savegamestrings[i]);
-
-	dp_translation = NULL;
     }
 }
 
@@ -1062,8 +1055,6 @@ void M_QuickSaveResponse(int key)
 
 void M_QuickSave(void)
 {
-    char *savegamestring;
-
     if (!usergame)
     {
 	S_StartSound(NULL,sfx_oof);
@@ -1081,14 +1072,8 @@ void M_QuickSave(void)
 	quickSaveSlot = -2;	// means to pick a slot now
 	return;
     }
-    // [crispy] print savegame name in golden letters
-    savegamestring = M_StringJoin(crstr[CR_GOLD],
-                                  savegamestrings[quickSaveSlot],
-                                  crstr[CR_NONE],
-                                  NULL);
     DEH_snprintf(tempstring, sizeof(tempstring),
-                 QSPROMPT, savegamestring);
-    free(savegamestring);
+                 QSPROMPT, savegamestrings[quickSaveSlot]);
     M_StartMessage(tempstring, M_QuickSaveResponse, true);
 }
 
@@ -1109,8 +1094,6 @@ void M_QuickLoadResponse(int key)
 
 void M_QuickLoad(void)
 {
-    char *savegamestring;
-
     // [crispy] allow quickloading game while multiplayer demo playback
     if (netgame && !demoplayback)
     {
@@ -1127,14 +1110,8 @@ void M_QuickLoad(void)
 	quickSaveSlot = -2;
 	return;
     }
-    // [crispy] print savegame name in golden letters
-    savegamestring = M_StringJoin(crstr[CR_GOLD],
-                                  savegamestrings[quickSaveSlot],
-                                  crstr[CR_NONE],
-                                  NULL);
     DEH_snprintf(tempstring, sizeof(tempstring),
-                 QLPROMPT, savegamestring);
-    free(savegamestring);
+                 QLPROMPT, savegamestrings[quickSaveSlot]);
     M_StartMessage(tempstring, M_QuickLoadResponse, true);
 }
 
@@ -2985,19 +2962,10 @@ void M_Drawer (void)
 
 	if (name[0] && (W_CheckNumForName(name) > 0 || alttext))
 	{
-	    // [crispy] shade unavailable menu items
-	    if ((currentMenu == &MainDef && i == savegame && (!usergame || gamestate != GS_LEVEL)) ||
-	        (currentMenu == &OptionsDef && i == endgame && (!usergame || netgame)) ||
-	        (currentMenu == &MainDef && i == loadgame && (netgame && !demoplayback)) ||
-	        (currentMenu == &MainDef && i == newgame && (demorecording || (netgame && !demoplayback))))
-	        dp_translation = cr[CR_DARK];
-
 	    if (W_CheckNumForName(name) > 0 && currentMenu->lumps_missing == -1)
 	    V_DrawPatchDirect (x, y, W_CacheLumpName(name, PU_CACHE));
 	    else if (alttext)
 		M_WriteText(x, y+8-(M_StringHeight(alttext)/2), alttext);
-
-	    dp_translation = NULL;
 	}
 	y += LINEHEIGHT;
     }
@@ -3130,7 +3098,7 @@ void M_Init (void)
     // [crispy] NRFTL / The Master Levels
     if (crispy->havenerve || crispy->havemaster)
     {
-        int i;
+        int i, j;
 
         NewDef.prevMenu = &EpiDef;
         EpisodeMenu[0].alphaKey = gamevariant == freedm ||
@@ -3150,10 +3118,30 @@ void M_Init (void)
             EpisodeMenu[EpiDef.numitems].alttext = "No Rest for the Living";
             EpiDef.numitems++;
 
-            // [crispy] render the episode menu with the HUD font
-            // if the graphics are not from the BFG Edition Doom 2 IWAD or from a PWAD
-            if (gamevariant != bfgedition &&
-                (i = W_CheckNumForName("M_EPI2")) != -1 && W_IsIWADLump(lumpinfo[i]))
+            i = W_CheckNumForName("M_EPI1");
+            j = W_CheckNumForName("M_EPI2");
+
+            // [crispy] render the episode menu with the HUD font ...
+            // ... if the graphics are not available
+            if (i != -1 && j != -1)
+            {
+                // ... or if the graphics are both from an IWAD
+                if (W_IsIWADLump(lumpinfo[i]) && W_IsIWADLump(lumpinfo[j]))
+                {
+                    const patch_t *pi, *pj;
+
+                    pi = W_CacheLumpNum(i, PU_CACHE);
+                    pj = W_CacheLumpNum(j, PU_CACHE);
+
+                    // ... and if the patch width for "Hell on Earth"
+                    //     is longer than "No Rest for the Living"
+                    if (SHORT(pi->width) > SHORT(pj->width))
+                    {
+                        EpiDef.lumps_missing = 1;
+                    }
+                }
+            }
+            else
             {
                 EpiDef.lumps_missing = 1;
             }
@@ -3165,9 +3153,11 @@ void M_Init (void)
             EpisodeMenu[EpiDef.numitems].alttext = "The Master Levels";
             EpiDef.numitems++;
 
+            i = W_CheckNumForName(EpiDef.numitems == 3 ? "M_EPI3" : "M_EPI2");
+
             // [crispy] render the episode menu with the HUD font
-            // if the graphics are not from a PWAD
-            if ((i = W_CheckNumForName("M_EPI1")) != -1 && W_IsIWADLump(lumpinfo[i]))
+            // if the graphics are not available or not from a PWAD
+            if (i == -1 || W_IsIWADLump(lumpinfo[i]))
             {
                 EpiDef.lumps_missing = 1;
             }
