@@ -537,9 +537,10 @@ void P_MobjThinker (mobj_t* mobj)
 	return MusInfoThinker(mobj);
     }
     // [crispy] suppress interpolation of player missiles for the first tic
-    if (mobj->interp == -1)
+    // and Archvile fire to mitigate it being spawned at the wrong location
+    if (mobj->interp < 0)
     {
-        mobj->interp = false;
+        mobj->interp++;
     }
     else
     // [AM] Handle interpolation unless we're an active player.
