@@ -38,6 +38,7 @@
 #include "doomkeys.h"
 
 #include "g_game.h"
+#include "a11y.h" // [crispy] A11Y
 
 #include "st_stuff.h"
 #include "st_lib.h"
@@ -519,9 +520,9 @@ void ST_refreshBackground(boolean force)
 	}
 
 	// [crispy] center unity rerelease wide status bar
-	if (sbar->width > ORIGWIDTH && sbar->leftoffset == 0)
+	if (SHORT(sbar->width) > ORIGWIDTH && SHORT(sbar->leftoffset) == 0)
 	{
-	    V_DrawPatch(ST_X + (ORIGWIDTH - sbar->width) / 2, 0, sbar);
+	    V_DrawPatch(ST_X + (ORIGWIDTH - SHORT(sbar->width)) / 2, 0, sbar);
 	}
 	else
 	{
@@ -777,7 +778,7 @@ ST_Responder (event_t* ev)
 	if (plyr->cheats & CF_GODMODE)
 	{
 	  if (plyr->mo)
-	    plyr->mo->health = 100;
+	    plyr->mo->health = deh_god_mode_health;
 	  
 	  plyr->health = deh_god_mode_health;
 	  plyr->message = DEH_String(STSTR_DQDON);
@@ -1698,6 +1699,12 @@ void ST_doPaletteStuff(void)
 	    cnt = bzc;
     }
 	
+    // [crispy] A11Y
+    if (!a11y_palette_changes)
+    {
+	palette = 0;
+    }
+    else
     if (cnt)
     {
 	palette = (cnt+7)>>3;
