@@ -142,6 +142,12 @@ void P_RecursiveSound(sector_t * sec, int soundblocks)
 
 void P_NoiseAlert(mobj_t * target, mobj_t * emmiter)
 {
+    // [crispy] monsters are deaf with NOTARGET cheat
+    if (target && target->player && (target->player->cheats & CF_NOTARGET))
+    {
+        return;
+    }
+
     soundtarget = target;
     validcount++;
     P_RecursiveSound(emmiter->subsector->sector, 0);
@@ -546,6 +552,11 @@ boolean P_LookForPlayers(mobj_t * actor, boolean allaround)
             return false;       // done looking
 
         player = &players[actor->lastlook];
+
+        // [crispy] monsters don't look for players with NOTARGET cheat
+        if (player->cheats & CF_NOTARGET)
+            continue;
+
         if (player->health <= 0)
             continue;           // dead
         if (!P_CheckSight(actor, player->mo))
