@@ -447,7 +447,7 @@ void D_DoomMain(void)
     if (!M_ParmExists("-noautoload"))
     {
         char *autoload_dir;
-        autoload_dir = M_GetAutoloadDir("hexen.wad");
+        autoload_dir = M_GetAutoloadDir("hexen.wad", true);
         // TODO? DEH_AutoLoadPatches(autoload_dir);
         W_AutoLoadWADs(autoload_dir);
         free(autoload_dir);
