@@ -405,7 +405,9 @@ void G_BuildTiccmd (ticcmd_t* cmd, int maketic)
     if (joyxmove < 0
         || joyxmove > 0  
         || gamekeydown[key_right]
-        || gamekeydown[key_left]) 
+        || gamekeydown[key_left]
+        || mousebuttons[mousebturnright]
+        || mousebuttons[mousebturnleft])
         turnheld += ticdup; 
     else 
         turnheld = 0; 
@@ -418,12 +420,12 @@ void G_BuildTiccmd (ticcmd_t* cmd, int maketic)
     // let movement keys cancel each other out
     if (strafe) 
     { 
-        if (gamekeydown[key_right]) 
+        if (gamekeydown[key_right] || mousebuttons[mousebturnright])
         {
             // fprintf(stderr, "strafe right\n");
             side += sidemove[speed]; 
         }
-        if (gamekeydown[key_left]) 
+        if (gamekeydown[key_left] || mousebuttons[mousebturnleft])
         {
             //	fprintf(stderr, "strafe left\n");
             side -= sidemove[speed]; 
@@ -436,9 +438,9 @@ void G_BuildTiccmd (ticcmd_t* cmd, int maketic)
     } 
     else 
     { 
-        if (gamekeydown[key_right]) 
+        if (gamekeydown[key_right] || mousebuttons[mousebturnright])
             cmd->angleturn -= angleturn[tspeed]; 
-        if (gamekeydown[key_left]) 
+        if (gamekeydown[key_left] || mousebuttons[mousebturnleft])
             cmd->angleturn += angleturn[tspeed]; 
         if (joyxmove > 0) 
             cmd->angleturn -= angleturn[tspeed]; 
